local SLOT_1 = ActionButton3
local SLOT_2 = ActionButton4
local SLOT_3 = ActionButton5
local SLOT_4 = ActionButton6
local SLOT_5 = ActionButton7

local RECHARGE = 45
local LEFT = 46

local is_player_in_combat = false;

local settings = Settings()

local defaults = {

	recharge = {
		active = true,
		labelPositionY = 45,
		labelPositionX = 10,
		showLabels = false,
		font = "ZoFontWindowTitle",
		fontColor = { 
			r = 1,
			g = 1,
			b = 1,
			a = 1}},
	
	left = {
		active = false,
		labelPositionY = 25,
		labelPositionX = -10,
		showLabels = false,
		font = "ZoFontGame",
		fontColor = { 
			r = 0,
			g = 1,
			b = 0,
			a = 1}}
}



function createLabels()

	local button1_recharge = UIFrame(SLOT_1, 1, RECHARGE)
	local button2_recharge = UIFrame(SLOT_2, 2, RECHARGE)
	local button3_recharge = UIFrame(SLOT_3, 3, RECHARGE)
	local button4_recharge = UIFrame(SLOT_4, 4, RECHARGE)
	local button5_recharge = UIFrame(SLOT_5, 5, RECHARGE)

	local button1_left = UIFrame(SLOT_1, 6, LEFT)
	local button2_left = UIFrame(SLOT_2, 7, LEFT)
	local button3_left = UIFrame(SLOT_3, 8, LEFT)
	local button4_left = UIFrame(SLOT_4, 9, LEFT)
	local button5_left = UIFrame(SLOT_5, 10, LEFT)
	
	buttons_recharge = {button1_recharge:createActionButtonControl(), 
						button2_recharge:createActionButtonControl(), 
						button3_recharge:createActionButtonControl(), 
						button4_recharge:createActionButtonControl(), 
						button5_recharge:createActionButtonControl()}
						
	buttons_left = {button1_left:createActionButtonControl(), 
					button2_left:createActionButtonControl(), 
					button3_left:createActionButtonControl(), 
					button4_left:createActionButtonControl(), 
					button5_left:createActionButtonControl()}
end


local function setLabelsRecharge(id, buttonControl, abilityCost, abilityType)
	
	
	local regen = 0
	
	if(abilityType == POWERTYPE_STAMINA) then
		if is_player_in_combat then
			regen = GetPlayerStat(STAT_STAMINA_REGEN_COMBAT, STAT_BONUS_OPTION_APPLY_BONUS, STAT_SOFT_CAP_OPTION_APPLY_SOFT_CAP)
		else
			regen = GetPlayerStat(STAT_STAMINA_REGEN_IDLE, STAT_BONUS_OPTION_APPLY_BONUS, STAT_SOFT_CAP_OPTION_APPLY_SOFT_CAP)
		end
	elseif(abilityType == POWERTYPE_MAGICKA) then
		if is_player_in_combat then
			regen = GetPlayerStat(STAT_MAGICKA_REGEN_COMBAT, STAT_BONUS_OPTION_APPLY_BONUS, STAT_SOFT_CAP_OPTION_APPLY_SOFT_CAP)
		else
			regen = GetPlayerStat(STAT_MAGICKA_REGEN_IDLE, STAT_BONUS_OPTION_APPLY_BONUS, STAT_SOFT_CAP_OPTION_APPLY_SOFT_CAP)
		end
	else
		return
	end
	
	local current, maximum, e_maximum = GetUnitPower("player", abilityType)
	
	local time_to_reload = abilityCost / regen

	
	if(current < abilityCost) then
	
		if(regen ~= 0) then
			local result = time_to_reload - (current / regen)
			result = math.ceil(result)
		
			buttonControl.label:SetHidden(false)
			buttonControl.label:SetText(result)
		
		end
	else
		setLabelBlank(buttonControl)
	end
	
end

local function setLabelsLeft(id, buttonControl, abilityCost, abilityType)

	local current, maximum, e_maximum = GetUnitPower("player", abilityType)
	
	if(abilityCost > 0) then
		if(current >= abilityCost) then
	
			local result = current / abilityCost
		
			result = math.floor(result)
	
			buttonControl.label:SetHidden(false)
			buttonControl.label:SetText(result)
		
		else
			setLabelBlank(buttonControl)
		end
		
	end
	
end

function setLabelBlank(button)
	button.label:SetText("")
	button.label:SetHidden(true)
end

local function RechargeCounterUpdate()
	
	if ZO_OptionsWindow:IsHidden() then
	
		if not ZO_ActionBar1:IsHidden() then
			for i = 1, 5 do
				setLabelsRecharge(i, buttons_recharge[i], GetSlotAbilityCost(i + 2))
			end
		else
			for i = 1, 5 do
				setLabelBlank(buttons_recharge[i])
			end
		end
		
		db.recharge.showLabels = false
	end
		
end

local function ActionCounterUpdate()

	if ZO_OptionsWindow:IsHidden() then
	
		if not ZO_ActionBar1:IsHidden() then
			for i = 1, 5 do
				setLabelsLeft(i, buttons_left[i], GetSlotAbilityCost(i + 2))
			end
		else
			for i = 1, 5 do
				setLabelBlank(buttons_left[i])
			end
		end
		
		db.left.showLabels = false
	end
	
end

local function Update(event)
	if(db.recharge.active) then
		RechargeCounterUpdate()
	end
	
	if(db.left.active) then
		ActionCounterUpdate()
	end
end


local function createDB()
	RechargeCounterSavedVars = RechargeCounterSavedVars or {}
	for i,j in pairs(defaults) do
	    if type(RechargeCounterSavedVars[i]) == "nil" then
	        RechargeCounterSavedVars[i] = j
	    end
	end
	db = RechargeCounterSavedVars
end


local function CombatStateChanged( eventCode, state )
	is_player_in_combat = state
end


local function InitEvents( eventCode, addonName )
	if(addonName == "RechargeCounter") then
	
	createDB()
	createLabels()
	settings:createOptionsMenu()
	
    RechargeCounter:RegisterForEvent(EVENT_PLAYER_COMBAT_STATE, CombatStateChanged)
	EVENT_MANAGER:RegisterForUpdate("RechargeCounter", 50, Update)

	ZO_ActionBar1:SetDrawLayer(1)
	db.showLabels = false
	
	end
end

function Initialize()

	EVENT_MANAGER:RegisterForEvent("RechargeCounter", EVENT_ADD_ON_LOADED, InitEvents)

end