local LAM = LibStub("LibAddonMenu-1.0")

Settings = {}
Settings.__index = Settings
setmetatable(Settings, {__call = function (class, ...) return class.new(...) end})

Settings.fonts = {"ZoFontGame", "ZoFontWindowTitle", "ZoFontBookLetter", "ZoFontBookLetterTitle", "ZoFontBossName", "ZoFontGameSmall"}

function Settings.new()
	local self = setmetatable({}, Settings)
	self.panelID = LAM:CreateControlPanel("RechargeCounter_Settings", "Recharge Counter")
	return self
end

function Settings:createOptionsMenu()
	self:createRechargeSettings()
	self:createActionLeftSettings()
end

function Settings:createRechargeSettings()
	
	LAM:AddHeader(self.panelID, "RechargeCounter_Header1", "Recharge Counter")

	LAM:AddCheckbox(self.panelID, "RechargeCounter_activateRechargeCounter", "Activate Action Counter",
				"Activates the Recharge Counter",
				function() 
					return db.recharge.active
				end,
			
				function()
					db.recharge.active = not db.recharge.active		
					
				end)
	
	LAM:AddCheckbox(self.panelID, "RechargeCounter_ShowLabels", "Show position of labels",
				"Show the label position for setup",
				function() 
					return db.recharge.showLabels 
				end,
				
				function()
					db.recharge.showLabels = not db.recharge.showLabels
					
					if db.recharge.showLabels then
						
						for i = 1, 5 do
							buttons_recharge[i].label:SetHidden(false)
							buttons_recharge[i].label:SetText("X")
						end

					else
						
						for i = 1, 5 do
							setLabelBlank(buttons_recharge[i])
						end
	
					end
					
				end)
				
	

	LAM:AddDropdown(self.panelID, "RechargeCounter_Font", "Font", "The font to use for the labels",
				self.fonts, 
				function() 
					return db.recharge.font 
				end,
				
				function(value)
					db.recharge.font = value
					
					for i = 1, 5 do
						buttons_recharge[i].label:SetFont(db.recharge.font)
					end
					
				end)
						
			
	LAM:AddSlider(self.panelID, "RechargeCounter_PositionY", "Y-Axis Label Position", "Set the Y-axis position of the labels", -50, 70,
            1, 
			function()
				return db.recharge.labelPositionY
			end, 
			
			function (value)
				db.recharge.labelPositionY = value
				
				for i = 1, 5 do
					buttons_recharge[i].label:SetAnchor(CENTER, buttons_recharge[i], CENTER, db.recharge.labelPositionX, db.recharge.labelPositionY)
				end

			end)
			
	LAM:AddSlider(self.panelID, "RechargeCounter_PositionX", "X-Axis Label Position", "Set the X-axis position of the labels", -50, 50,
            1, 
			function()
				return db.recharge.labelPositionX
			end, 
			
			function (value)
				db.recharge.labelPositionX = value
				
				for i = 1, 5 do
					buttons_recharge[i].label:SetAnchor(CENTER, buttons_recharge[i], CENTER, db.recharge.labelPositionX, db.recharge.labelPositionY)
				end

			end)
			
	LAM:AddColorPicker(self.panelID, "RechargeCounter_FontColor", "Font Color", "Select a color for the font",
			function() 
				return db.recharge.fontColor.r, db.recharge.fontColor.g, db.recharge.fontColor.b, db.recharge.fontColor.a
			end,
			
			function(r,g,b,a)
				db.recharge.fontColor.r = r
				db.recharge.fontColor.g = g
				db.recharge.fontColor.b = b
				db.recharge.fontColor.a = a

				for i = 1, 5 do				
					buttons_recharge[i].label:SetColor(db.recharge.fontColor.r, db.recharge.fontColor.g, db.recharge.fontColor.b, db.recharge.fontColor.a)
				end

			end)
			

end

function Settings:createActionLeftSettings()

	LAM:AddHeader(self.panelID, "RechargeCounter_Header2", "Action Counter")

	LAM:AddCheckbox(self.panelID, "RechargeCounter_activateActionCounter", "Activate Action Counter",
				"Activates the Action Counter (shows you how often you can use a skill until you are out of magicka/stamina)",
				function() 
					return db.left.active
				end,
				
				function()
					db.left.active = not db.left.active					
				end)
	
	LAM:AddCheckbox(self.panelID, "RechargeCounter_ShowLabelsAction", "Show position of labels",
				"Show the label position for setup",
				function() 
					return db.left.showLabels 
				end,
				
				function()
					db.left.showLabels = not db.left.showLabels
					
					if db.left.showLabels then
						
						for i = 1, 5 do
							buttons_left[i].label:SetHidden(false)
							buttons_left[i].label:SetText("X")
						end

					else
						
						for i = 1, 5 do
							setLabelBlank(buttons_left[i])
						end
	
					end
					
				end)
	

	LAM:AddDropdown(self.panelID, "RechargeCounter_FontAction", "Font", "The font to use for the labels",
				self.fonts, 
				function() 
					return db.left.font 
				end,
				
				function(value)
					db.left.font = value
					
					for i = 1, 5 do
						buttons_left[i].label:SetFont(db.left.font)
					end
					
				end)
						
			
	LAM:AddSlider(self.panelID, "RechargeCounter_PositionYAction", "Y-Axis Label Position", "Set the Y-axis position of the labels", -50, 70,
            1, 
			function()
				return db.left.labelPositionY
			end, 
			
			function (value)
				db.left.labelPositionY = value
				
				for i = 1, 5 do
					buttons_left[i].label:SetAnchor(CENTER, buttons_left[i], CENTER, db.left.labelPositionX, db.left.labelPositionY)
				end

			end)
			
	LAM:AddSlider(self.panelID, "RechargeCounter_PositionXAction", "X-Axis Label Position", "Set the X-axis position of the labels", -50, 50,
            1, 
			function()
				return db.left.labelPositionX
			end, 
			
			function (value)
				db.left.labelPositionX = value
				
				for i = 1, 5 do
					buttons_left[i].label:SetAnchor(CENTER, buttons_left[i], CENTER, db.left.labelPositionX, db.left.labelPositionY)
				end

			end)
			
	LAM:AddColorPicker(self.panelID, "RechargeCounter_FontColorAction", "Font Color", "Select a color for the font",
			function() 
				return db.left.fontColor.r, db.left.fontColor.g, db.left.fontColor.b, db.left.fontColor.a
			end,
			
			function(r,g,b,a)
				db.left.fontColor.r = r
				db.left.fontColor.g = g
				db.left.fontColor.b = b
				db.left.fontColor.a = a

				for i = 1, 5 do				
					buttons_left[i].label:SetColor(db.left.fontColor.r, db.left.fontColor.g, db.left.fontColor.b, db.left.fontColor.a)
				end

			end)
end